django-coop
===============================================
An work-in-progress to build collaborative organizations management server for the Social and Solidarity Economy Sector.
Django-coop manages organizations, contact informations, members, relations between organizations, places, impact areas, tags, categories, exchanges (products, services, partnerships).
It feeds selected data through a D2R server to a RDF aggregation platform that can acts as a hub for different networks.

Installation intructions are (in french...)  on the `wiki <http://redmine.django.coop/projects/django-coop/wiki/Installation>`_.

License
=======
django-coop uses the same license as Django (BSD).
django-coop development is currently funded by `CREDIS <http://credis.org/>`_, FSE (European Social Fund) and `Conseil Régional Auvergne <http://www.auvergne.fr/>`_.
